@@ -6,8 +6,8 @@ import re
 from django.utils.translation import ugettext_lazy as _
 from askbot.conf.settings_wrapper import settings
 from askbot.conf.super_groups import DATA_AND_FORMATTING
-from askbot.deps.livesettings import ConfigurationGroup
-from askbot.deps.livesettings import BooleanValue, StringValue, LongStringValue
+from livesettings.values import ConfigurationGroup
+from livesettings.values import BooleanValue, StringValue, LongStringValue
 from askbot import const
 
 MARKUP = ConfigurationGroup(
