@@ -156,7 +156,7 @@ TAG_LIST_FORMAT_CHOICES = (
 PAGE_SIZE_CHOICES = (('10', '10',), ('30', '30',), ('50', '50',),)
 ANSWERS_PAGE_SIZE = 10
 USER_POSTS_PAGE_SIZE = 10
-QUESTIONS_PER_PAGE_USER_CHOICES = ((10, u'10'), (30, u'30'), (50, u'50'),)
+QUESTIONS_PER_PAGE_USER_CHOICES = ((10, '10'), (30, '30'), (50, '50'),)
 TAGS_PAGE_SIZE = 60
 
 UNANSWERED_QUESTION_MEANING_CHOICES = (
