@@ -19,7 +19,7 @@ import askbot.utils.timezone
 
 from django.conf import settings as django_settings
 from django.core.exceptions import ObjectDoesNotExist
-from django.core.urlresolvers import reverse
+from django.urls import reverse
 from django.http import Http404
 from django.utils.translation import ugettext as _
 
@@ -102,9 +102,9 @@ class RssIndividualQuestionFeed(Feed):
         if item.post_type == "question":
             title = item.thread.title
         elif item.post_type == "answer":
-            title = u'Answer by %s for %s ' % (item.author, item.thread._question_post().summary)
+            title = 'Answer by %s for %s ' % (item.author, item.thread._question_post().summary)
         elif item.post_type == "comment":
-            title = u'Comment by %s for %s' % (item.author, item.parent.summary)
+            title = 'Comment by %s for %s' % (item.author, item.parent.summary)
         return title
 
     def item_description(self, item):
