@@ -13,9 +13,9 @@ from django.forms.utils import ErrorList
 from django.utils import timezone
 from django.utils.html import strip_tags
 from django.utils.translation import ugettext_lazy as _
-from django.utils.translation import ungettext_lazy, string_concat
+from django.utils.translation import ungettext_lazy
 from askbot.utils.translation import get_language
-from django.utils.text import get_text_list
+from django.utils.text import get_text_list, format_lazy
 from django.contrib.auth.models import User
 from django_countries import countries
 from askbot.utils.forms import NextUrlField, UserNameField
@@ -42,7 +42,7 @@ def split_tags(data):
 def should_use_recaptcha(user):
     """True if user must use recaptcha"""
     return askbot_settings.USE_RECAPTCHA and \
-        (user.is_anonymous() or user.is_watched())
+        (user.is_anonymous or user.is_watched())
 
 
 def cleanup_dict(dictionary, key, empty_value):
@@ -61,7 +61,7 @@ def format_form_errors(form):
     If there are no errors, returns empty string
     """
     if form.errors:
-        errors = form.errors.values()
+        errors = list(form.errors.values())
         if len(errors) == 1:
             return errors[0]
         else:
@@ -186,10 +186,10 @@ class CountryField(forms.ChoiceField):
         except AttributeError:
             from django_countries import data
             country_choices = list()
-            for key, name in data.COUNTRIES.items():
+            for key, name in list(data.COUNTRIES.items()):
                 country_choices.append((key, name))
 
-        country_choices = sorted(country_choices, cmp=lambda a, b: cmp(a[1], b[1]))
+        country_choices = sorted(country_choices, key=lambda c: c[1])
 
         country_choices = (('unknown', _('select country')),) + tuple(country_choices)
         kwargs['choices'] = kwargs.pop('choices', country_choices)
@@ -231,14 +231,14 @@ class CountedWordsField(forms.CharField):
                                  self.min_words - 1) % (self.min_words - 1)
             # TODO - space is not used in Chinese
             raise forms.ValidationError(
-                string_concat(self.field_name, ' ', msg)
+                format_lazy('{} {}', self.field_name, msg)
             )
 
         if word_count > self.max_words:
             msg = ungettext_lazy('must be < %d word', 'must be < %d words',
                                  self.max_words + 1) % (self.max_words + 1)
             raise forms.ValidationError(
-                string_concat(self.field_name, ' ', msg))
+                format_lazy('{} {}', self.field_name, msg))
         return value
 
 
@@ -381,7 +381,7 @@ class EditorField(forms.CharField):
             ) % {'length': self.min_length}
             raise forms.ValidationError(msg)
 
-        if self.user.is_anonymous():
+        if self.user.is_anonymous:
             # we postpone this validation if user is posting
             # before logging in, up until publishing the post
             return value
@@ -389,7 +389,7 @@ class EditorField(forms.CharField):
         try:
             self.user.assert_can_post_text(value)
         except PermissionDenied as err:
-            raise forms.ValidationError(unicode(err))
+            raise forms.ValidationError(str(err))
 
         return value
 
@@ -512,12 +512,12 @@ class TagNamesField(forms.CharField):
             if cleaned_tag not in cleaned_entered_tags:
                 cleaned_entered_tags.append(clean_tag(tag))
 
-        result = u' '.join(cleaned_entered_tags)
+        result = ' '.join(cleaned_entered_tags)
 
         if len(result) > 125:  # magic number!, the same as max_length in db
             raise forms.ValidationError(self.error_messages['max_length'])
 
-        return u' '.join(cleaned_entered_tags)
+        return ' '.join(cleaned_entered_tags)
 
 
 class WikiField(forms.BooleanField):
@@ -559,7 +559,7 @@ class SortField(forms.ChoiceField):
 
     def clean(self, value):
         value = value or self.default
-        if value not in dict(self.choices).keys():
+        if value not in list(dict(self.choices).keys()):
             value = self.default
         return value
 
@@ -636,7 +636,7 @@ class ShowQuestionForm(forms.Form):
         or invalid"""
         if self._errors:
             # since the form is always valid, clear the errors
-            logging.error(unicode(self._errors))
+            logging.error(str(self._errors))
             self._errors = {}
 
         in_data = self.get_pruned_data()
@@ -737,7 +737,7 @@ class ChangeUserStatusForm(forms.Form):
         super(ChangeUserStatusForm, self).__init__(*arg, **kwarg)
 
         # Select user_status_choices depending on status of the moderator
-        if moderator.is_authenticated():
+        if moderator.is_authenticated:
             if moderator.is_administrator():
                 user_status_choices = ADMINISTRATOR_STATUS_CHOICES
             elif moderator.is_moderator():
@@ -857,7 +857,7 @@ class FeedbackForm(forms.Form):
 
     def clean(self):
         super(FeedbackForm, self).clean()
-        if self.user and self.user.is_anonymous():
+        if self.user and self.user.is_anonymous:
             need_email = not bool(self.cleaned_data.get('no_email', False))
             email = self.cleaned_data.get('email', '').strip()
             if need_email and email == '':
@@ -907,7 +907,7 @@ class PostPrivatelyForm(forms.Form, FormWithHideableFields):
         user = self._user
         return (
             askbot_settings.GROUPS_ENABLED and
-            user and user.is_authenticated() and
+            user and user.is_authenticated and
             user.can_make_group_private_posts()
         )
 
@@ -960,7 +960,7 @@ class PostAsSomeoneForm(forms.Form):
         then we would not have to have two almost identical clean functions?
         """
         username = self.cleaned_data.get('post_author_username', '').strip()
-        initial_username = unicode(self.fields['post_author_username'].initial)
+        initial_username = str(self.fields['post_author_username'].initial)
         if username and username == initial_username:
             self.cleaned_data['post_author_username'] = ''
         return self.cleaned_data['post_author_username']
@@ -969,7 +969,7 @@ class PostAsSomeoneForm(forms.Form):
         """if value is the same as initial, it is reset to
         empty string"""
         email = self.cleaned_data.get('post_author_email', '').strip()
-        initial_email = unicode(self.fields['post_author_email'].initial)
+        initial_email = str(self.fields['post_author_email'].initial)
         if email == initial_email:
             email = ''
         if email != '':
@@ -1027,7 +1027,7 @@ class AskForm(PostAsSomeoneForm, PostPrivatelyForm):
         self.fields['ask_anonymously'] = forms.BooleanField(
             label=_('post anonymously'), required=False)
 
-        if user.is_anonymous() or not askbot_settings.ALLOW_ASK_ANONYMOUSLY:
+        if user.is_anonymous or not askbot_settings.ALLOW_ASK_ANONYMOUSLY:
             self.hide_field('ask_anonymously')
 
         if askbot.is_multilingual():
@@ -1061,7 +1061,7 @@ class AskWidgetForm(forms.Form, FormWithHideableFields):
         super(AskWidgetForm, self).__init__(*args, **kwargs)
         self.fields['title'] = TitleField()
         # hide ask_anonymously field
-        if user.is_anonymous() or not askbot_settings.ALLOW_ASK_ANONYMOUSLY:
+        if user.is_anonymous or not askbot_settings.ALLOW_ASK_ANONYMOUSLY:
             self.hide_field('ask_anonymously')
         self.fields['text'] = QuestionEditorField(user=user)
         if not include_text:
@@ -1268,7 +1268,7 @@ class RevisionForm(forms.Form):
         date_format = '%c'
         rev_choices = list()
         for r in revisions:
-            rev_details = u'%s - %s (%s) %s' % (
+            rev_details = '%s - %s (%s) %s' % (
                 r[0], r[1], r[2].strftime(date_format), r[3])
             rev_choices.append((r[0], rev_details))
 
@@ -1373,7 +1373,7 @@ class EditTagWikiForm(forms.Form):
 
 class EditUserForm(forms.Form):
     email = forms.EmailField(
-        label=u'Email', required=False, max_length=255,
+        label='Email', required=False, max_length=255,
         widget=forms.TextInput(attrs={'size': 35}))
 
     realname = forms.CharField(
@@ -1531,7 +1531,7 @@ class EditUserEmailFeedsForm(forms.Form):
 
     def set_initial_values(self, user=None):
         from askbot import models
-        KEY_MAP = dict([(v, k) for k, v in self.FORM_TO_MODEL_MAP.iteritems()])
+        KEY_MAP = dict([(v, k) for k, v in self.FORM_TO_MODEL_MAP.items()])
         if user is not None:
             settings = models.EmailFeedSetting.objects.filter(subscriber=user)
             initial_values = {}
@@ -1561,7 +1561,7 @@ class EditUserEmailFeedsForm(forms.Form):
         # TODO: refactor this - too hacky
         # should probably use model form instead
 
-        return self.FORM_TO_MODEL_MAP.values()
+        return list(self.FORM_TO_MODEL_MAP.values())
 
     def set_frequency(self, frequency='n'):
         data = {
@@ -1582,7 +1582,7 @@ class EditUserEmailFeedsForm(forms.Form):
         """
         from askbot import models
         changed = False
-        for form_field, feed_type in self.FORM_TO_MODEL_MAP.items():
+        for form_field, feed_type in list(self.FORM_TO_MODEL_MAP.items()):
             s, created = models.EmailFeedSetting.objects.get_or_create(
                     subscriber=user, feed_type=feed_type)
             if save_unbound:
