@@ -1,4 +1,4 @@
-from __future__ import print_function
+
 #todo: http://stackoverflow.com/questions/837828/how-to-use-a-slug-in-django
 DEBUGME = False
 import os
@@ -192,7 +192,7 @@ class X(object):#
         for rev in rev_group:
             rev_type = cls.get_post_revision_type(rev)
             rev_types[rev_type] = 1
-        rev_types = rev_types.keys()
+        rev_types = list(rev_types.keys())
 
         #make sure that exclusive rev modes are not mixed
         exclusive = cls.exclusive_revision_modes
@@ -259,7 +259,7 @@ class X(object):#
     #crude method of getting id provider name from the url
     @classmethod
     def get_openid_provider_name(cls, openid_url):
-        openid_str = unicode(openid_url)
+        openid_str = str(openid_url)
         bits = openid_str.split('/')
         base_url = bits[2] #assume this is base url
         url_bits = base_url.split('.')
@@ -297,20 +297,18 @@ it may be helpful to split this procedure in two:\n
 """
     args = 'se_dump_dir'
 
-    option_list = BaseCommand.option_list + (
-        make_option('-r', '--read-dump',
+    def add_arguments(self, parser):
+        parser.add_argument(
+            '-r', '--read-dump',
             action='store_true',
             dest='read_dump',
             default=False,
-            help='Only read the the dump'
-        ),
-        make_option('-p', '--process-data',
+            help='Only read the the dump')
+        parser.add_argument('-p', '--process-data',
             action='store_true',
             dest='process_data',
             default=False,
-            help='Only process the data, assuming that the dump is loaded'
-        )
-    )
+            help='Only process the data, assuming that the dump is loaded')
 
     def handle(self, *arg, **kwarg):
 
@@ -332,7 +330,7 @@ it may be helpful to split this procedure in two:\n
         if not importer_is_ready():
             raise CommandError(
                 "Looks like stackexchange tables are not yet initialized in the database.\n"
-                "Please, run command: \npython manage.py syncdb\n"
+                "Please, run command: \npython manage.py migrate\n"
                 "then import the data."
             )
 
@@ -775,8 +773,8 @@ it may be helpful to split this procedure in two:\n
 
     def _report_missing_badges(self):
         d = self._missing_badges
-        unused = [name for name in d.keys() if d[name] == 0]
-        dropped = [unidecode(name) for name in d.keys() if d[name] > 0]
+        unused = [name for name in list(d.keys()) if d[name] == 0]
+        dropped = [unidecode(name) for name in list(d.keys()) if d[name] > 0]
         print('Warning - following unsupported badges were dropped:')
         print(', '.join(dropped))
         sys.stdout.flush()
@@ -886,7 +884,7 @@ it may be helpful to split this procedure in two:\n
                 try:
                     field_type = model._meta.get_field(field_name)
                 except fields.FieldDoesNotExist as e:
-                    print(u"Warning: %s" % unicode(e))
+                    print("Warning: %s" % str(e))
                     continue
                 field_value = se_parser.parse_value(col.text, field_type)
                 setattr(model_entry, field_name, field_value)
@@ -934,7 +932,7 @@ it may be helpful to split this procedure in two:\n
                     u_openid.last_used_timestamp = se_u.last_login_date
                     u_openid.save()
                 except AssertionError:
-                    print(u'User %s (id=%d) does not have openid' % \
+                    print('User %s (id=%d) does not have openid' % \
                             (unidecode(se_u.display_name), se_u.id))
                     sys.stdout.flush()
                 except IntegrityError:
