@@ -1,16 +1,16 @@
-from django.core.management.base import NoArgsCommand
+from django.core.management import BaseCommand
 from django.db.models import F
 from django.utils.translation import override
 
 from askbot.models import Post
 
 
-class Command(NoArgsCommand):
+class Command(BaseCommand):
     """
     Fix incorrectly denormalized thread points by copying the value from
     its question.
     """
-    def handle_noargs(self, *args, **kwargs):
+    def handle(self, *args, **kwargs):
         questions = (Post.objects
                      .filter(post_type='question')
                      .exclude(points=F('thread__points'))
