@@ -6,7 +6,6 @@ from django.contrib.sitemaps import ping_google
 from django.utils import html
 from django.conf import settings as django_settings
 from django.contrib.auth.models import User
-from django.core import urlresolvers
 from django.db import models
 from django.utils import html as html_utils
 from django.utils import timezone
@@ -18,13 +17,13 @@ from django.utils.http import urlquote as django_urlquote
 from django.core import exceptions as django_exceptions
 from django.core import cache
 from django.core.exceptions import ValidationError
-from django.core.urlresolvers import reverse
+from django.urls import reverse
 from django.contrib.contenttypes.models import ContentType
 
 import askbot
 
 from askbot import signals
-from askbot.utils.loading import load_module, load_plugin
+from askbot.utils.loading import load_plugin, load_function
 from askbot.utils.slug import slugify
 from askbot import const
 from askbot.models.tag import Tag, MarkedTag
@@ -82,8 +81,8 @@ def default_html_moderator(post):
 
 
 class PostToGroup(models.Model):
-    post = models.ForeignKey('Post')
-    group = models.ForeignKey('Group')
+    post = models.ForeignKey('Post', on_delete=models.CASCADE)
+    group = models.ForeignKey('Group', on_delete=models.CASCADE)
 
     class Meta:
         unique_together = ('post', 'group')
@@ -101,7 +100,7 @@ class PostQuerySet(models.query.QuerySet):
     def get_for_user(self, user):
         from askbot.models.user import Group
         if askbot_settings.GROUPS_ENABLED:
-            if user is None or user.is_anonymous():
+            if user is None or user.is_anonymous:
                 groups = [Group.objects.get_global_group()]
             else:
                 groups = user.get_groups()
@@ -246,7 +245,7 @@ class PostManager(BaseQuerySetManager):
             author=author,
             revised_at=added_at,
             text=text,
-            comment=unicode(const.POST_STATUS['default_version']),
+            comment=str(const.POST_STATUS['default_version']),
             by_email=by_email,
             ip_addr=ip_addr
         )
@@ -303,7 +302,7 @@ class PostManager(BaseQuerySetManager):
 
         comments_reversed = askbot_settings.COMMENTS_REVERSED
 
-        if visitor.is_anonymous():
+        if visitor.is_anonymous:
             if comments_reversed:
                 comments = list(qs.order_by('-added_at'))
             else:
@@ -325,7 +324,7 @@ class PostManager(BaseQuerySetManager):
             post.set_cached_comments(post_map[post.id])
 
         # Old Post.get_comment(self, visitor=None) method:
-        #        if visitor.is_anonymous():
+        #        if visitor.is_anonymous:
         #            return self.comments.order_by('added_at')
         #        else:
         #            upvoted_by_user = list(self.comments.filter(votes__user=visitor).distinct())
@@ -382,18 +381,21 @@ class Post(models.Model):
 
     # Answer or Question for Comment
     parent = models.ForeignKey('Post', blank=True, null=True,
-                               related_name='comments')
+                               related_name='comments',
+                               on_delete=models.CASCADE)
     thread = models.ForeignKey('Thread', blank=True, null=True, default=None,
-                               related_name='posts')
+                               related_name='posts',
+                               on_delete=models.CASCADE)
     # nullable b/c we have to first save post and then add link to current
     # revision (which has a non-nullable fk to post)
     current_revision = models.ForeignKey('PostRevision', blank=True, null=True,
-                                         related_name='rendered_posts')
+                                         related_name='rendered_posts',
+                                         on_delete=models.CASCADE)
     # used for group-private posts
     groups = models.ManyToManyField('Group', through='PostToGroup',
                                     related_name='group_posts')
 
-    author = models.ForeignKey(User, related_name='posts')
+    author = models.ForeignKey(User, related_name='posts', on_delete=models.CASCADE)
     added_at = models.DateTimeField(default=timezone.now)
 
     # endorsed == accepted as best in the case of answer
@@ -402,7 +404,8 @@ class Post(models.Model):
     # note: accepted answer is also denormalized on the Thread model
     endorsed = models.BooleanField(default=False, db_index=True)
     endorsed_by = models.ForeignKey(User, null=True, blank=True,
-                                    related_name='endorsed_posts')
+                                    related_name='endorsed_posts',
+                                    on_delete=models.CASCADE)
     endorsed_at = models.DateTimeField(null=True, blank=True)
 
     # denormalized data: the core approval of the posts is made
@@ -413,14 +416,16 @@ class Post(models.Model):
     deleted = models.BooleanField(default=False, db_index=True)
     deleted_at = models.DateTimeField(null=True, blank=True)
     deleted_by = models.ForeignKey(User, null=True, blank=True,
-                                   related_name='deleted_posts')
+                                   related_name='deleted_posts',
+                                   on_delete=models.CASCADE)
 
     wiki = models.BooleanField(default=False)
     wikified_at = models.DateTimeField(null=True, blank=True)
 
     locked = models.BooleanField(default=False)
     locked_by = models.ForeignKey(User, null=True, blank=True,
-                                  related_name='locked_posts')
+                                  related_name='locked_posts',
+                                  on_delete=models.CASCADE)
     locked_at = models.DateTimeField(null=True, blank=True)
 
     points = models.IntegerField(default=0, db_column='score')
@@ -431,7 +436,7 @@ class Post(models.Model):
     offensive_flag_count = models.SmallIntegerField(default=0)
 
     last_edited_at = models.DateTimeField(null=True, blank=True)
-    last_edited_by = models.ForeignKey(User, null=True, blank=True, related_name='last_edited_posts')
+    last_edited_by = models.ForeignKey(User, null=True, blank=True, related_name='last_edited_posts', on_delete=models.CASCADE)
 
     html = models.TextField(null=True)  # html rendition of the latest revision
     text = models.TextField(null=True)  # denormalized copy of latest revision
@@ -452,6 +457,7 @@ class Post(models.Model):
     objects = PostManager()
 
     class Meta:
+        ordering = [ '-last_edited_at', '-points' ]
         app_label = 'askbot'
         db_table = 'askbot_post'
 
@@ -700,7 +706,7 @@ class Post(models.Model):
         except KeyError:
             raise NotImplementedError
 
-        return load_module(renderer_path)
+        return load_function(renderer_path)
 
     def has_group(self, group):
         """true if post belongs to the group"""
@@ -826,7 +832,7 @@ class Post(models.Model):
         child_rev_ids = set(child_revs.values_list('pk', flat=True))
 
         rev_ids = list(self_rev_ids | child_rev_ids)
-        
+
         from askbot.tasks import delete_update_notifications_task
         task_args = (rev_ids, keep_activity)
         defer_celery_task(delete_update_notifications_task, args=task_args)
@@ -970,18 +976,18 @@ class Post(models.Model):
             if not question_post:
                 question_post = self.thread._question_post()
             if no_slug:
-                url = u'%(base)s?answer=%(id)d#post-id-%(id)d' % {
-                    'base': urlresolvers.reverse('question', args=[question_post.id]),
+                url = '%(base)s?answer=%(id)d#post-id-%(id)d' % {
+                    'base': reverse('question', args=[question_post.id]),
                     'id': self.id
                 }
             else:
-                url = u'%(base)s%(slug)s/?answer=%(id)d#post-id-%(id)d' % {
-                    'base': urlresolvers.reverse('question', args=[question_post.id]),
+                url = '%(base)s%(slug)s/?answer=%(id)d#post-id-%(id)d' % {
+                    'base': reverse('question', args=[question_post.id]),
                     'slug': django_urlquote(slugify(self.thread.title)),
                     'id': self.id
                 }
         elif self.is_question():
-            url = urlresolvers.reverse('question', args=[self.id])
+            url = reverse('question', args=[self.id])
             if thread:
                 url += django_urlquote(slugify(thread.title)) + '/'
             elif no_slug is False:
@@ -1031,7 +1037,7 @@ class Post(models.Model):
 
         super(Post, self).delete(**kwargs)
 
-    def __unicode__(self):
+    def __str__(self):
         if self.is_question():
             return self.thread.title
         else:
@@ -1059,7 +1065,7 @@ class Post(models.Model):
             title = title or self.thread.title
             tags = tags or self.thread.tagnames
             body_text = body_text or self.text
-            return u'{}\n\n{}\n\n{}'.format(title, tags, body_text)
+            return '{}\n\n{}\n\n{}'.format(title, tags, body_text)
         return body_text or self.text
 
     def get_snippet(self, max_length=None):
@@ -1588,7 +1594,7 @@ class Post(models.Model):
         return when, who
 
     def tagname_meta_generator(self):
-        return u','.join([unicode(tag) for tag in self.get_tag_names()])
+        return ','.join([str(tag) for tag in self.get_tag_names()])
 
     def get_parent_post(self):
         """returns parent post or None
@@ -1684,7 +1690,7 @@ class Post(models.Model):
         if not self.is_answer():
             raise NotImplementedError
 
-        if user.is_anonymous():
+        if user.is_anonymous:
             return None
 
         votes = self.votes.filter(user=user)
@@ -1700,7 +1706,7 @@ class Post(models.Model):
                 raise exceptions.QuestionHidden(_('Sorry, this content is not available'))
         if self.deleted:
             message = _('Sorry, this content is no longer available')
-            if user.is_anonymous():
+            if user.is_anonymous:
                 raise exceptions.QuestionHidden(message)
             try:
                 user.assert_can_see_deleted_post(self)
@@ -1716,7 +1722,7 @@ class Post(models.Model):
             raise exceptions.QuestionHidden(message)
         if self.deleted:
             message = _('Sorry, this content is no longer available')
-            if user.is_anonymous():
+            if user.is_anonymous:
                 raise exceptions.AnswerHidden(message)
             try:
                 user.assert_can_see_deleted_post(self)
@@ -1751,7 +1757,7 @@ class Post(models.Model):
             raise NotImplementedError
 
         message = _('This post is temporarily not available')
-        if user.is_anonymous():
+        if user.is_anonymous:
             raise exception(message)
         else:
             user_groups_ids = user.get_groups().values_list('id', flat=True)
@@ -1911,7 +1917,7 @@ class Post(models.Model):
             is_anonymous=is_anonymous,
             revised_at=revised_at,
             tagnames=self.thread.tagnames,
-            summary=unicode(comment),
+            summary=str(comment),
             text=text,
             by_email=by_email,
             email_address=email_address,
@@ -1998,7 +2004,7 @@ class Post(models.Model):
             else:
                 attr = None
             if attr is not None:
-                return u'%s %s' % (self.thread.title, unicode(attr))
+                return '%s %s' % (self.thread.title, str(attr))
             else:
                 return self.thread.title
         raise NotImplementedError
@@ -2096,7 +2102,7 @@ class PostRevisionManager(models.Manager):
             # set default summary
             if revision.summary == '':
                 if revision.revision == 1:
-                    revision.summary = unicode(const.POST_STATUS['default_version'])
+                    revision.summary = str(const.POST_STATUS['default_version'])
                 else:
                     revision.summary = 'No.%s Revision' % revision.revision
             revision.save()
@@ -2140,15 +2146,15 @@ class PostRevision(models.Model):
     )
 
     post = models.ForeignKey('askbot.Post', related_name='revisions',
-                             null=True, blank=True)
+                             null=True, blank=True, on_delete=models.CASCADE)
     revision = models.PositiveIntegerField()
-    author = models.ForeignKey('auth.User', related_name='%(class)ss')
+    author = models.ForeignKey('auth.User', related_name='%(class)ss', on_delete=models.CASCADE)
     revised_at = models.DateTimeField()
     summary = models.CharField(max_length=300, blank=True)
     text = models.TextField(blank=True)
 
     approved = models.BooleanField(default=False, db_index=True)
-    approved_by = models.ForeignKey(User, null=True, blank=True)
+    approved_by = models.ForeignKey(User, null=True, blank=True, on_delete=models.CASCADE)
     approved_at = models.DateTimeField(null=True, blank=True)
 
     by_email = models.BooleanField(default=False)  # true, if edited by email
@@ -2248,8 +2254,8 @@ class PostRevision(models.Model):
         else:
             raise ValueError()
 
-    def __unicode__(self):
-        return u'%s - revision %s of %s' % (self.post.post_type, self.revision,
+    def __str__(self):
+        return '%s - revision %s of %s' % (self.post.post_type, self.revision,
                                             self.title)
 
     def parent(self):
@@ -2313,9 +2319,9 @@ class PostRevision(models.Model):
 
 class PostFlagReason(models.Model):
     added_at = models.DateTimeField()
-    author = models.ForeignKey('auth.User')
+    author = models.ForeignKey('auth.User', on_delete=models.CASCADE)
     title = models.CharField(max_length=128)
-    details = models.ForeignKey(Post, related_name='post_reject_reasons')
+    details = models.ForeignKey(Post, related_name='post_reject_reasons', on_delete=models.CASCADE)
 
     class Meta:
         app_label = 'askbot'
@@ -2328,8 +2334,8 @@ class DraftAnswer(DraftContent):
     note that unlike ``AnonymousAnswer`` the foreign key
     is going to ``Thread`` as it should.
     """
-    thread = models.ForeignKey('Thread', related_name='draft_answers')
-    author = models.ForeignKey(User, related_name='draft_answers')
+    thread = models.ForeignKey('Thread', related_name='draft_answers', on_delete=models.CASCADE)
+    author = models.ForeignKey(User, related_name='draft_answers', on_delete=models.CASCADE)
 
     class Meta:
         app_label = 'askbot'
@@ -2337,7 +2343,7 @@ class DraftAnswer(DraftContent):
 
 class AnonymousAnswer(AnonymousContent):
     """Todo: re-route the foreign key to ``Thread``"""
-    question = models.ForeignKey(Post, related_name='anonymous_answers')
+    question = models.ForeignKey(Post, related_name='anonymous_answers', on_delete=models.CASCADE)
 
     def publish(self, user):
         added_at = timezone.now()
