@@ -9,6 +9,8 @@ from django.utils import timezone
 from jsonfield import JSONField
 from django_countries.fields import CountryField
 
+# the mere fact that this method's use case is so specific,
+# that the parameter is called "user" ...
 def get_profile_cache_key(user):
     if user.pk:
         return 'askbot-profile-{}'.format(user.pk)
@@ -103,12 +105,13 @@ def add_profile_properties(cls):
 
 
 class UserProfile(models.Model):
-    #text_search_vector           | tsvector                 | 
+    #text_search_vector           | tsvector                 |
     auth_user_ptr = models.OneToOneField(
                                 User,
                                 parent_link=True,
                                 related_name='askbot_profile',
-                                primary_key=True
+                                primary_key=True,
+                                on_delete=models.CASCADE
                             )
     avatar_urls = JSONField(default={})
     status = models.CharField(
@@ -209,7 +212,12 @@ class UserProfile(models.Model):
         self.social_sharing_mode = const.SHARE_NOTHING
 
     def get_cache_key(self):
-        return get_profile_cache_key(self.auth_user_ptr)
+        try:
+            # Django <=1.10
+            return get_profile_cache_key(self.auth_user_ptr)
+        except AttributeError:
+            # Django ==1.11
+            return get_profile_cache_key(self)
 
     def update_cache(self):
         key = self.get_cache_key()
@@ -221,7 +229,7 @@ class UserProfile(models.Model):
 
 
 class LocalizedUserProfile(models.Model):
-    auth_user = models.ForeignKey(User, related_name='localized_askbot_profiles')
+    auth_user = models.ForeignKey(User, related_name='localized_askbot_profiles', on_delete=models.CASCADE)
     about = models.TextField(blank=True)
     language_code = LanguageCodeField(db_index=True)
     reputation = models.PositiveIntegerField(default=0, db_index=True)
