@@ -102,7 +102,7 @@ class PageLoadTestCase(AskbotTestCase):
             url_info = 'getting url %s' % url
         if data:
             url_info += '?' + '&'.join(['%s=%s' % (k, v) for k, v in data.items()])
-        print(url_info)
+        # print(url_info)
 
         # if redirect expected, but we wont' follow
         if status_code == 302 and follow:
@@ -111,11 +111,11 @@ class PageLoadTestCase(AskbotTestCase):
             return
 
         r = self.client.get(url, data=data, follow=follow)
-        if hasattr(self.client, 'redirect_chain'):
-            print('redirect chain: %s' % ','.join(self.client.redirect_chain))
+        # if hasattr(self.client, 'redirect_chain'):
+        #     print('redirect chain: %s' % ','.join(self.client.redirect_chain))
 
-        if r.status_code != status_code:
-            print('Error in status code for url: %s' % url)
+        # if r.status_code != status_code:
+        #     print('Error in status code for url: %s' % url)
 
         self.assertEqual(r.status_code, status_code)
 
@@ -135,7 +135,7 @@ class PageLoadTestCase(AskbotTestCase):
             if isinstance(templates, list):
                 #asuming that there is more than one template
                 template_names = [t.name for t in templates]
-                print('templates are %s' % ','.join(template_names))
+                # print('templates are %s' % ','.join(template_names))
                 self.assertIn(template, template_names)
             else:
                 raise Exception('unexpected error while runnig test')
