@@ -5,7 +5,8 @@ import time
 from askbot.search.state_manager import SearchState
 from django.conf import settings as django_settings
 from django.contrib.auth.models import User
-from django.core import cache, urlresolvers
+from django.urls import reverse
+from django.core import cache
 from django.core.cache.backends.dummy import DummyCache
 from django.core.cache.backends.locmem import LocMemCache
 
@@ -19,7 +20,7 @@ from askbot.models import Thread
 from askbot.models import Tag
 from askbot.models import Group
 from askbot.search.state_manager import DummySearchState
-import simplejson
+import json
 from django.utils import timezone
 from askbot.tests.utils import skipIf, with_settings
 from askbot.conf import settings as askbot_settings
@@ -133,7 +134,7 @@ class PostModelTests(AskbotTestCase):
         th.title = 'lala-x-lala'
         p = Post(id=3, post_type='question')
         p._thread_cache = th  # cannot assign non-Thread instance directly
-        expected_url = urlresolvers.reverse('question', kwargs={'id': 3}) \
+        expected_url = reverse('question', kwargs={'id': 3}) \
                                                                 + th.title + '/'
         self.assertEqual(expected_url, p.get_absolute_url(thread=th))
         self.assertTrue(p._thread_cache is th)
@@ -143,7 +144,7 @@ class PostModelTests(AskbotTestCase):
         p = Post(id=3, post_type='question')
         th = lambda:1
         th.title = 'lala-x-lala'
-        expected_url = urlresolvers.reverse('question', kwargs={'id': 3}) \
+        expected_url = reverse('question', kwargs={'id': 3}) \
                                                                 + th.title + '/'
         self.assertEqual(expected_url, p.get_absolute_url(thread=th))
         self.assertTrue(p._thread_cache is th)
@@ -305,7 +306,7 @@ class ThreadTagModelsTests(AskbotTestCase):
 
             user = User.objects.get(id=thread.last_activity_by_id)
             self.assertEqual(user.id, thread._last_activity_by_cache.id)
-            self.assertTrue(thread.last_activity_by is thread._last_activity_by_cache)
+            self.assertEqual(thread.last_activity_by, thread._last_activity_by_cache)
 
 
 class ThreadRenderLowLevelCachingTests(AskbotTestCase):
@@ -465,7 +466,7 @@ class ThreadRenderCacheUpdateTests(AskbotTestCase):
 
     def test_post_question(self):
         self.assertEqual(0, Post.objects.count())
-        response = self.client.post(urlresolvers.reverse('ask'), data={
+        response = self.client.post(reverse('ask'), data={
             'title': 'test question title',
             'text': 'test body text',
             'tags': 'tag1 tag2',
@@ -476,7 +477,7 @@ class ThreadRenderCacheUpdateTests(AskbotTestCase):
 
         self.assertEqual('test question title', question.thread.title)
         self.assertEqual('test body text', question.text)
-        self.assertItemsEqual(['tag1', 'tag2'], list(question.thread.tags.values_list('name', flat=True)))
+        self.assertCountEqual(['tag1', 'tag2'], list(question.thread.tags.values_list('name', flat=True)))
         self.assertEqual(0, question.thread.answer_count)
 
         self.assertTrue(question.thread.summary_html_cached())  # <<< make sure that caching backend is set up properly (i.e. it's not dummy)
@@ -495,7 +496,7 @@ class ThreadRenderCacheUpdateTests(AskbotTestCase):
         time.sleep(1.5) # compensate for 1-sec time resolution in some databases
 
         response = self.client.post(
-            urlresolvers.reverse('edit_question', kwargs={'id': question.id}),
+            reverse('edit_question', kwargs={'id': question.id}),
             data={
                 'title': 'edited title',
                 'text': 'edited body text',
@@ -524,14 +525,14 @@ class ThreadRenderCacheUpdateTests(AskbotTestCase):
     def test_retag_question(self):
         self.assertEqual(0, Post.objects.count())
         question = self.post_question()
-        response = self.client.post(urlresolvers.reverse('retag_question', kwargs={'id': question.id}), data={
+        response = self.client.post(reverse('retag_question', kwargs={'id': question.id}), data={
             'tags': 'tag1 tag2',
         })
         self.assertEqual(1, Post.objects.count())
         question = Post.objects.all()[0]
         self.assertRedirects(response=response, expected_url=question.get_absolute_url())
 
-        self.assertItemsEqual(['tag1', 'tag2'], list(question.thread.tags.values_list('name', flat=True)))
+        self.assertCountEqual(['tag1', 'tag2'], list(question.thread.tags.values_list('name', flat=True)))
 
         self.assertTrue(question.thread.summary_html_cached())  # <<< make sure that caching backend is set up properly (i.e. it's not dummy)
         html = self._html_for_question(question)
@@ -553,7 +554,7 @@ class ThreadRenderCacheUpdateTests(AskbotTestCase):
         self.client.logout()
         self.client.login(username='user2', password='pswd')
         time.sleep(1.5) # compensate for 1-sec time resolution in some databases
-        response = self.client.post(urlresolvers.reverse('answer', kwargs={'id': question.id}), data={
+        response = self.client.post(reverse('answer', kwargs={'id': question.id}), data={
             'text': 'answer longer than 10 chars',
         })
         self.assertEqual(2, Post.objects.count())
@@ -590,7 +591,7 @@ class ThreadRenderCacheUpdateTests(AskbotTestCase):
         self.client.logout()
         self.client.login(username='user2', password='pswd')
         response = self.client.post(
-            urlresolvers.reverse(
+            reverse(
                 'edit_answer',
                 kwargs={'id': answer.id}
             ),
@@ -622,7 +623,7 @@ class ThreadRenderCacheUpdateTests(AskbotTestCase):
 
         # INFO: We need to pass some headers to make question() view believe we're not a robot
         self.client.get(
-            urlresolvers.reverse('question', kwargs={'id': question.id}),
+            reverse('question', kwargs={'id': question.id}),
             {},
             follow=True, # the first view redirects to the full question url (with slug in it), so we have to follow that redirect
             HTTP_ACCEPT_LANGUAGE='en',
@@ -645,12 +646,12 @@ class ThreadRenderCacheUpdateTests(AskbotTestCase):
         self.client.logout()
         self.client.login(username='user2', password='pswd')
         response = self.client.post(
-            urlresolvers.reverse('vote'),
+            reverse('vote'),
             data={'type': '1', 'postId': question.id},
             HTTP_X_REQUESTED_WITH='XMLHttpRequest'
         ) # use AJAX request
         self.assertEqual(200, response.status_code)
-        data = simplejson.loads(response.content)
+        data = json.loads(response.content)
 
         self.assertEqual(1, data['success'])
         self.assertEqual(6, data['count'])  # 6 == question.points(5) + 1
@@ -664,12 +665,12 @@ class ThreadRenderCacheUpdateTests(AskbotTestCase):
         ###
 
         response = self.client.post(
-            urlresolvers.reverse('vote'),
+            reverse('vote'),
             data={'type': '2', 'postId': question.id},
             HTTP_X_REQUESTED_WITH='XMLHttpRequest'
         ) # use AJAX request
         self.assertEqual(200, response.status_code)
-        data = simplejson.loads(response.content)
+        data = json.loads(response.content)
 
         self.assertEqual(1, data['success'])
         self.assertEqual(5, data['count'])  # 6 == question.points(6) - 1
@@ -687,12 +688,12 @@ class ThreadRenderCacheUpdateTests(AskbotTestCase):
         self.client.logout()
         self.client.login(username='user2', password='pswd')
         response = self.client.post(
-            urlresolvers.reverse('vote'),
+            reverse('vote'),
             data={'type': '0', 'postId': answer.id},
             HTTP_X_REQUESTED_WITH='XMLHttpRequest'
         ) # use AJAX request
         self.assertEqual(200, response.status_code)
-        data = simplejson.loads(response.content)
+        data = json.loads(response.content)
 
         self.assertEqual(1, data['success'])
 
