@@ -1,26 +1,21 @@
 """Utilities for loading modules"""
+import importlib
+
 from django.conf import settings as django_settings
 
+
 def load_module(mod_path):
     """an equivalent of:
     from some.where import module
     import module
-
-    TODO: is this the same as the following?
-    try:
-        from django.utils.module_loading import import_string
-    except ImportError:
-        from django.utils.module_loading import import_by_path as import_string
     """
-    assert(mod_path[0] != '.')
-    path_bits = mod_path.split('.')
-    if len(path_bits) > 1:
-        mod_name = path_bits.pop()
-        mod_prefix = '.'.join(path_bits)
-        _mod = __import__(mod_prefix, globals(), locals(), [mod_name,], -1)
-        return getattr(_mod, mod_name)
-    else:
-        return __import__(mod_path, globals(), locals(), [], -1)
+    return importlib.import_module(mod_path)
+
+
+def load_function(func_path):
+    mod_path, func = func_path.rsplit('.', 1)
+    mod = load_module(mod_path)
+    return getattr(mod, func)
 
 
 def load_plugin(setting_name, default_path):
@@ -32,7 +27,7 @@ def load_plugin(setting_name, default_path):
                         setting_name,
                         default_path
                     )
-    return load_module(python_path)
+    return load_function(python_path)
 
 
 def module_exists(mod_path):
