@@ -5,7 +5,7 @@ This module contains a collection of views displaying all sorts of secondary and
 """
 from django.shortcuts import render_to_response, get_object_or_404
 from django.conf import settings as django_settings
-from django.core.urlresolvers import reverse
+from django.urls import reverse
 from django.core.paginator import Paginator, EmptyPage, InvalidPage
 from django.shortcuts import render
 from django.template import RequestContext
@@ -15,7 +15,7 @@ from django.http import Http404
 from django.http import HttpResponse
 from django.http import HttpResponseForbidden
 from django.http import HttpResponseRedirect
-from django.core.urlresolvers import reverse
+from django.urls import reverse
 from django.utils import translation
 from django.utils.translation import ugettext as _
 from django.utils.translation import ugettext_lazy
@@ -32,7 +32,7 @@ from askbot.utils.functions import encode_jwt
 from askbot.mail.messages import FeedbackEmail
 from askbot.models import get_users_by_role, BadgeData, Award, User, Tag
 from askbot.models import badges as badge_data
-from askbot.skins.loaders import render_text_into_skin
+from askbot.skins.shortcuts import render_text_into_skin
 from askbot.utils.decorators import moderators_only
 from askbot.utils.forms import get_next_url
 from askbot.utils import functions
@@ -126,7 +126,7 @@ def faq(request):
 @csrf.csrf_protect
 def feedback(request):
     if askbot_settings.FEEDBACK_MODE == 'auth-only':
-        if request.user.is_anonymous():
+        if request.user.is_anonymous:
             message = _('Please sign in or register to send your feedback')
             request.user.message_set.create(message=message)
             next_jwt = encode_jwt({'next_url': request.path})
@@ -148,7 +148,7 @@ def feedback(request):
                 'user': request.user
             }
 
-            if request.user.is_authenticated():
+            if request.user.is_authenticated:
                 data['email'] = request.user.email
             else:
                 data['email'] = form.cleaned_data.get('email', None)
@@ -179,13 +179,13 @@ def badges(request):#user status/reputation system
     #todo: supplement database data with the stuff from badges.py
     if askbot_settings.BADGES_MODE != 'public':
         raise Http404
-    known_badges = badge_data.BADGES.keys()
+    known_badges = list(badge_data.BADGES.keys())
     badges = BadgeData.objects.filter(slug__in=known_badges) #pylint: disable=no-member
 
-    badges = filter(lambda v: v.is_enabled(), badges)
+    badges = [v for v in badges if v.is_enabled()]
 
     my_badge_ids = list()
-    if request.user.is_authenticated():
+    if request.user.is_authenticated:
         my_badge_ids = Award.objects.filter( #pylint: disable=no-member
                                 user=request.user
                             ).values_list(
