@@ -15,7 +15,7 @@ import logging
 import math
 import os
 import operator
-import urllib
+import urllib.request, urllib.parse, urllib.error
 
 from django.db.models import Count
 from django.db.models import Q
@@ -24,17 +24,16 @@ from django.contrib.auth.decorators import login_required
 from django.core import exceptions as django_exceptions
 from django.core.paginator import Paginator, EmptyPage, InvalidPage
 from django.contrib.contenttypes.models import ContentType
-from django.core.urlresolvers import reverse
+from django.urls import reverse
 from django.shortcuts import get_object_or_404
 from django.shortcuts import render
-from django.http import HttpResponse, HttpResponseForbidden
-from django.http import HttpResponseRedirect, Http404, HttpResponseBadRequest
-from django.http import StreamingHttpResponse
+from django.http import HttpResponse, HttpResponseForbidden, FileResponse
+from django.http import HttpResponseRedirect, Http404
+from django.utils.text import format_lazy
 from django.utils.translation import get_language
-from django.utils.translation import string_concat
 from django.utils.translation import ugettext as _
 from django.utils.translation import ungettext
-import simplejson
+import json
 from django.utils import timezone
 from django.utils.html import strip_tags as strip_all_tags
 from django.views.decorators import csrf
@@ -45,9 +44,7 @@ from askbot.utils.functions import encode_jwt
 from askbot.utils.transaction import defer_celery_task
 from askbot.mail import send_mail
 from askbot.utils.translation import get_language
-from askbot.mail.messages import (AccountManagementRequest,
-                                  UnsubscribeLink)
-from askbot.utils.file_utils import read_file_chunkwise
+from askbot.mail.messages import UnsubscribeLink
 from askbot.utils.http import get_request_info
 from askbot.utils import decorators
 from askbot.utils import functions
@@ -62,6 +59,7 @@ from askbot.models.badges import award_badges_signal
 from askbot.models.tag import format_personal_group_name
 from askbot.models.post import PostRevision
 from askbot.search.state_manager import SearchState
+from askbot.utils.http import get_request_params
 from askbot.utils import url_utils
 from askbot.utils.loading import load_module
 from askbot.utils.akismet_utils import akismet_check_spam
@@ -71,7 +69,7 @@ def owner_or_moderator_required(func):
     def wrapped_func(request, profile_owner, context):
         if profile_owner == request.user:
             pass
-        elif request.user.is_authenticated():
+        elif request.user.is_authenticated:
             if request.user.can_moderate_user(profile_owner):
                 pass
             else:
@@ -79,7 +77,8 @@ def owner_or_moderator_required(func):
                 #as this one should be accessible to all
                 return HttpResponseRedirect(request.path)
         else:
-            next_url = request.path + '?' + urllib.urlencode(request.REQUEST)
+            params = get_request_params(request)
+            next_url = request.path + '?' + urllib.parse.urlencode(params)
             params = '?next=%s' % encode_jwt({'next_url': next_url})
             return HttpResponseRedirect(url_utils.get_login_url() + params)
         return func(request, profile_owner, context)
@@ -89,14 +88,14 @@ def owner_or_moderator_required(func):
 def clear_new_notifications(request):
     """clears all new notifications for logged in user"""
     user = request.user
-    if user.is_anonymous():
+    if user.is_anonymous:
         raise django_exceptions.PermissionDenied
 
     activity_types = const.RESPONSE_ACTIVITY_TYPES_FOR_DISPLAY
     activity_types += (
         const.TYPE_ACTIVITY_MENTION,
     )
-    post_data = simplejson.loads(request.body)
+    post_data = json.loads(request.body)
     memo_set = models.ActivityAuditStatus.objects.filter(
         id__in=post_data['memo_ids'],
         activity__activity_type__in=activity_types,
@@ -107,7 +106,7 @@ def clear_new_notifications(request):
 
 @decorators.ajax_only
 def delete_notifications(request):
-    post_data = simplejson.loads(request.body)
+    post_data = json.loads(request.body)
     memo_set = models.ActivityAuditStatus.objects.filter(
         id__in=post_data['memo_ids'],
         user=request.user
@@ -168,7 +167,7 @@ def show_users(request, by_group=False, group_id=None, group_slug=None):
                                                 )
                     user_ids = memberships.values_list('user__id', flat=True)
                     users = users.filter(id__in=user_ids)
-                    if request.user.is_authenticated():
+                    if request.user.is_authenticated:
                         membership = request.user.get_group_membership(group)
                         if membership:
                             user_membership_level = membership.get_level_display()
@@ -185,7 +184,7 @@ def show_users(request, by_group=False, group_id=None, group_slug=None):
 
     is_paginated = True
 
-    form = forms.ShowUsersForm(request.REQUEST)
+    form = forms.ShowUsersForm(getattr(request, request.method))
     form.full_clean() # always valid
     sort_method = form.cleaned_data['sort']
     page = form.cleaned_data['page']
@@ -269,7 +268,7 @@ def show_users(request, by_group=False, group_id=None, group_slug=None):
 def manage_account(request, subject, context):
     """Allows requesting a data export, termination of account,
     anonymization of data and termination of the account."""
-    if request.user.is_anonymous():
+    if request.user.is_anonymous:
         return HttpResponseForbidden()
 
     if not request.user.can_manage_account(subject):
@@ -322,7 +321,7 @@ def manage_account(request, subject, context):
 @decorators.ajax_only
 @decorators.get_only
 def get_todays_backup_file_name(request, id):
-    if request.user.is_anonymous():
+    if request.user.is_anonymous:
         return {'error': 'permission denied'}
 
     try:
@@ -338,7 +337,7 @@ def get_todays_backup_file_name(request, id):
 
 def download_user_data(request, id, file_name):
     """allows authorized user to download a given file"""
-    if request.user.is_anonymous():
+    if request.user.is_anonymous:
         return HttpResponseForbidden()
 
     if os.path.sep in file_name:
@@ -354,14 +353,11 @@ def download_user_data(request, id, file_name):
 
     directory = subject.get_data_export_dir()
     file_path = os.path.join(directory, file_name)
-    if not os.path.isfile(os.path.join(directory, file_path)):
-        return Http404
 
-    response = StreamingHttpResponse(content_type='application/force-download')
-    response['Content-Disposition'] = 'attachment; filename=%s' % file_name
-    file_obj = open(os.path.join(directory, file_name))
-    response.streaming_content = read_file_chunkwise(file_obj)
-    return response
+    try:
+        return FileResponse(open(file_path, 'rb'), as_attachment=True, filename=file_name)
+    except FileNotFoundError:
+        return Http404
 
 
 @csrf.csrf_protect
@@ -369,7 +365,7 @@ def user_moderate(request, subject, context):
     """User subview for moderation"""
     moderator = request.user
 
-    if not (moderator.is_authenticated() and moderator.can_moderate_user(subject)):
+    if not (moderator.is_authenticated and moderator.can_moderate_user(subject)):
         raise Http404
 
     user_rep_changed = False
@@ -393,7 +389,7 @@ def user_moderate(request, subject, context):
                     num_deleted = request.user.delete_all_content_authored_by_user(subject)
                     if num_deleted:
                         num_deleted_message = ungettext('%d post deleted', '%d posts deleted', num_deleted) % num_deleted
-                        user_status_changed_message = string_concat(user_status_changed_message, ', ', num_deleted_message)
+                        user_status_changed_message = format_lazy('{}, {}', user_status_changed_message, num_deleted_message)
             user_status_changed = True
         elif 'send_message' in request.POST:
             send_message_form = forms.SendMessageForm(request.POST)
@@ -411,7 +407,7 @@ def user_moderate(request, subject, context):
                         )
                     message_sent = True
                 except exceptions.EmailNotSent as e:
-                    email_error_message = unicode(e)
+                    email_error_message = str(e)
                 send_message_form = forms.SendMessageForm()
         else:
             reputation_change_type = None
@@ -551,7 +547,7 @@ def user_stats(request, user, context):
     question_filter = {}
 
     is_author = (request.user == user)
-    is_mod = request.user.is_authenticated() and request.user.is_administrator_or_moderator()
+    is_mod = request.user.is_authenticated and request.user.is_administrator_or_moderator()
     if not (is_mod or is_author):
         question_filter['is_anonymous'] = False
 
@@ -684,8 +680,8 @@ def user_stats(request, user, context):
         # "Assign" to its Badge
         badges_dict[award.badge].append(award)
 
-    badges = badges_dict.items()
-    badges.sort(key=operator.itemgetter(1), reverse=True)
+    badges = list(badges_dict.items())
+    badges.sort(key=lambda x:x[0].get_name(), reverse=True)
 
     user_groups = models.Group.objects.get_for_user(user = user)
     user_groups = user_groups.exclude_personal()
@@ -697,13 +693,13 @@ def user_stats(request, user, context):
     else:
         groups_membership_info = collections.defaultdict()
 
-    show_moderation_warning = (request.user.is_authenticated()
+    show_moderation_warning = (request.user.is_authenticated
                                 and request.user.pk == user.pk
                                 and (user.is_watched() or user.is_blocked())
                                 and (user.get_localized_profile().about or user.website)
                               )
     show_profile_info = ((not (user.is_watched() or user.is_blocked()))
-                          or (request.user.is_authenticated()
+                          or (request.user.is_authenticated
                               and (request.user.is_administrator_or_moderator()
                                    or user.pk == request.user.pk
                                   )
@@ -756,7 +752,7 @@ def user_stats(request, user, context):
 
 @decorators.ajax_only
 def get_user_description(request):
-    if request.user.is_anonymous():
+    if request.user.is_anonymous:
         if askbot_settings.CLOSED_FORUM_MODE:
             raise django_exceptions.PermissionDenied
 
@@ -773,7 +769,7 @@ def get_user_description(request):
 @decorators.ajax_only
 @decorators.post_only
 def set_user_description(request):
-    if request.user.is_anonymous():
+    if request.user.is_anonymous:
         raise django_exceptions.PermissionDenied
 
     if askbot_settings.READ_ONLY_MODE_ENABLED:
@@ -886,7 +882,7 @@ def user_recent(request, user, context):
                 # don't know what to do here...
                 event_title = ''
                 event_summary = ''
-                
+
             event = Event(
                 time=activity.active_at,
                 type=activity.activity_type,
@@ -927,7 +923,7 @@ def show_group_join_requests(request, user, context):
     join_requests = models.Activity.objects.filter(
                         activity_type=const.TYPE_ACTIVITY_ASK_TO_JOIN_GROUP,
                         content_type=group_content_type,
-                        object_id__in=groups_dict.keys()
+                        object_id__in=list(groups_dict.keys())
                     ).order_by('-active_at')
     data = {
         'active_tab':'users',
@@ -1012,12 +1008,14 @@ def user_responses(request, user, context):
     #2) load the activity notifications according to activity types
     #todo: insert pagination code here
     memo_set = request.user.get_notifications(activity_types)
+    # gravatar is a charfield in UserProfile and, as far as i understand
+    # Django, should be available as soon as we select_related('activity__
+    # user__askbot_profile')
     memo_set = memo_set.select_related(
                     'activity',
                     'activity__content_type',
                     'activity__question__thread',
                     'activity__user',
-                    'activity__user__askbot_profile__gravatar',
                 ).order_by(
                     '-activity__active_at'
                 )[:const.USER_VIEW_DATA_SIZE]
@@ -1057,7 +1055,7 @@ def user_responses(request, user, context):
         response_list.append(response)
 
     #4) sort by response id
-    response_list.sort(lambda x,y: cmp(y['question_id'], x['question_id']))
+    response_list.sort(key=lambda x: x['question_id'], reverse=True)
 
     #5) group responses by thread (response_id is really the question post id)
     last_question_id = None #flag to know if the question id is different
@@ -1073,7 +1071,7 @@ def user_responses(request, user, context):
             last_question_id = message['question_id']
 
     #6) sort responses by time
-    filtered_message_list.sort(lambda x,y: cmp(y['timestamp'], x['timestamp']))
+    filtered_message_list.sort(key=lambda x: x['timestamp'], reverse=True)
 
     data = {
         'active_tab':'users',
@@ -1081,7 +1079,7 @@ def user_responses(request, user, context):
         'tab_name' : 'inbox',
         'inbox_section': section,
         'page_title' : _('profile - responses'),
-        'messages' : filtered_message_list,
+        'notifications' : filtered_message_list,
     }
     context.update(data)
     template = 'user_inbox/responses.html'
@@ -1140,7 +1138,7 @@ def user_reputation(request, user, context):
                                         'question__thread',
                                         'user'
                                     )
-                                    
+
 
     def format_graph_data(raw_data, user):
         # prepare data for the graph - last values go in first
@@ -1227,7 +1225,7 @@ def user_favorites(request, user, context):
 @decorators.ajax_only
 @decorators.post_only
 def user_set_primary_language(request):
-    if request.user.is_anonymous():
+    if request.user.is_anonymous:
         raise django_exceptions.PermissionDenied
 
     form = forms.LanguageForm(request.POST)
@@ -1239,7 +1237,7 @@ def user_set_primary_language(request):
 
 @csrf.csrf_protect
 def user_select_languages(request, id=None, slug=None):
-    if request.user.is_anonymous():
+    if request.user.is_anonymous:
         raise django_exceptions.PermissionDenied
 
     user = get_object_or_404(models.User, id=id)
@@ -1285,7 +1283,7 @@ def user_select_languages(request, id=None, slug=None):
 
 @csrf.csrf_protect
 def user_unsubscribe(request):
-    form = forms.UnsubscribeForm(request.REQUEST)
+    form = forms.UnsubscribeForm(getattr(request,request.method))
     verified_email = ''
     if form.is_valid() == False:
         result = 'bad_input'
@@ -1301,7 +1299,7 @@ def user_unsubscribe(request):
             result = 'bad_input'
         except models.User.MultipleObjectsReturned:
             result = 'error'
-            logging.critical(u'unexpected error with data %s', unicode(form.cleaned_data))
+            logging.critical('unexpected error with data %s', str(form.cleaned_data))
         else:
             verified_email = user.email
             if user.email_key == key:#all we need is key
@@ -1440,20 +1438,20 @@ def user(request, id, slug=None, tab_name=None):
     if profile_owner.is_terminated():
         if request.user.pk == profile_owner.pk:
             return render(request, 'user_profile/account_terminated.html')
-        if request.user.is_authenticated():
+        if request.user.is_authenticated:
             if not request.user.is_administrator_or_moderator():
                 raise Http404
         else:
             raise Http404
 
     if profile_owner.is_blocked():
-        if request.user.is_anonymous() \
+        if request.user.is_anonymous \
             or not request.user.is_administrator_or_moderator():
             raise Http404
 
     if slugify(profile_owner.username) != slug:
         view_url = profile_owner.get_profile_url() + '?' \
-                                + urllib.urlencode(request.REQUEST)
+                                + urllib.parse.urlencode(getattr(request,request.method))
         return HttpResponseRedirect(view_url)
 
     if not tab_name:
@@ -1473,7 +1471,7 @@ def user(request, id, slug=None, tab_name=None):
         author=None,
         page=None,
         page_size=const.USER_POSTS_PAGE_SIZE,
-        user_logged_in=profile_owner.is_authenticated(),
+        user_logged_in=profile_owner.is_authenticated,
     )
 
     context = {
@@ -1494,7 +1492,7 @@ def groups(request, id = None, slug = None):
         raise Http404
 
     #6 lines of input cleaning code
-    if request.user.is_authenticated():
+    if request.user.is_authenticated:
         scope = request.GET.get('sort', 'all-groups')
         if scope not in ('all-groups', 'my-groups'):
             scope = 'all-groups'
@@ -1511,11 +1509,11 @@ def groups(request, id = None, slug = None):
     groups = groups.exclude_personal()
     groups = groups.annotate(users_count=Count('user_membership'))
 
-    user_can_add_groups = request.user.is_authenticated() and \
+    user_can_add_groups = request.user.is_authenticated and \
             request.user.is_administrator_or_moderator()
 
     groups_membership_info = collections.defaultdict()
-    if request.user.is_authenticated():
+    if request.user.is_authenticated:
         #collect group memberhship information
         groups_membership_info = request.user.get_groups_membership_info(groups)
 
